# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ChargeCaptureClaimCreation,
    ChargeCaptureClaimCreationPage,
    ChargeCaptureClaimCreationSortField,
    ChargeCaptureClaimCreationStatus,
    ChargeCaptureClaimCreationSummary,
)

__all__ = [
    "ChargeCaptureClaimCreation",
    "ChargeCaptureClaimCreationPage",
    "ChargeCaptureClaimCreationSortField",
    "ChargeCaptureClaimCreationStatus",
    "ChargeCaptureClaimCreationSummary",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Explanation(str, enum.Enum):
    ROUTING_FAILED = "Payer Routing and/or Billing Provider Routing Failed"
    PAYER_MATCH_FAILED = "No Effective Contract with Payer"
    BILLING_PROVIDER_MATCH_FAILED = "No Effective Contract with Billing Provider"
    COVERED_GEOGRAPHY_MATCH_FAILED = "No Effective Contract with Covered Geography"
    LINE_OF_BUSINESS_MATCH_FAILED = "No Effective Contract with Line of Business"
    INSURANCE_TYPE_MATCH_FAILED = "No Effective Contract with Insurance Type"
    RENDERING_PROVIDER_MATCH_FAILED = "No Effective Contract with Rendering Provider"
    RENDERING_PROVIDER_CREDENTIALING_CHECK_FAILED = "Rendering Provider Not Credentialed"
    _UNKNOWN = "__EXPLANATION_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Explanation":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        routing_failed: typing.Callable[[], T_Result],
        payer_match_failed: typing.Callable[[], T_Result],
        billing_provider_match_failed: typing.Callable[[], T_Result],
        covered_geography_match_failed: typing.Callable[[], T_Result],
        line_of_business_match_failed: typing.Callable[[], T_Result],
        insurance_type_match_failed: typing.Callable[[], T_Result],
        rendering_provider_match_failed: typing.Callable[[], T_Result],
        rendering_provider_credentialing_check_failed: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Explanation.ROUTING_FAILED:
            return routing_failed()
        if self is Explanation.PAYER_MATCH_FAILED:
            return payer_match_failed()
        if self is Explanation.BILLING_PROVIDER_MATCH_FAILED:
            return billing_provider_match_failed()
        if self is Explanation.COVERED_GEOGRAPHY_MATCH_FAILED:
            return covered_geography_match_failed()
        if self is Explanation.LINE_OF_BUSINESS_MATCH_FAILED:
            return line_of_business_match_failed()
        if self is Explanation.INSURANCE_TYPE_MATCH_FAILED:
            return insurance_type_match_failed()
        if self is Explanation.RENDERING_PROVIDER_MATCH_FAILED:
            return rendering_provider_match_failed()
        if self is Explanation.RENDERING_PROVIDER_CREDENTIALING_CHECK_FAILED:
            return rendering_provider_credentialing_check_failed()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.street_address_short_zip import StreetAddressShortZip


class NonInsurancePayerAddressUpdate_Remove(UniversalBaseModel):
    type: typing.Literal["remove"] = "remove"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class NonInsurancePayerAddressUpdate_Set(UniversalBaseModel):
    value: typing.Optional[StreetAddressShortZip] = None
    type: typing.Literal["set"] = "set"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


NonInsurancePayerAddressUpdate = typing.Union[NonInsurancePayerAddressUpdate_Remove, NonInsurancePayerAddressUpdate_Set]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
import uuid

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from ....commons.types.page_token import PageToken
from ....commons.types.provider_credentialing_span_id import ProviderCredentialingSpanId
from ....commons.types.regions import Regions
from .raw_client import AsyncRawV2Client, RawV2Client
from .types.provider_credentialing_span import ProviderCredentialingSpan
from .types.provider_credentialing_span_page import ProviderCredentialingSpanPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV2Client
        """
        return self._raw_client

    def create(
        self,
        *,
        rendering_provider_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        regions: Regions,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        rendering_provider_id : uuid.UUID
            The ID of the rendering provider covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the practice location at which the rendering provider is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        regions : Regions
            The states covered by the credentialing span. A span may be national and cover all states.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import uuid

        from candid import CandidApiClient
        from candid.resources.commons import Regions_States, State

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.credentialing.v_2.create(
            rendering_provider_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            contracting_provider_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            payer_uuid=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            regions=Regions_States(
                states=[State.AA, State.AA],
            ),
        )
        """
        _response = self._raw_client.create(
            rendering_provider_id=rendering_provider_id,
            contracting_provider_id=contracting_provider_id,
            payer_uuid=payer_uuid,
            regions=regions,
            start_date=start_date,
            end_date=end_date,
            submitted_date=submitted_date,
            payer_loaded_date=payer_loaded_date,
            request_options=request_options,
        )
        return _response.data

    def get(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.credentialing.v_2.get(
            provider_credentialing_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.get(provider_credentialing_id, request_options=request_options)
        return _response.data

    def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        provider_id: typing.Optional[uuid.UUID] = None,
        as_rendering_provider: typing.Optional[bool] = None,
        as_contracting_provider: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpanPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        provider_id : typing.Optional[uuid.UUID]
            Filter to a particular provider. Use in conjunction as_rendering_provider and as_contracting_provider.

        as_rendering_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a rendering provider. To use this filter provider_id is required.

        as_contracting_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a contracting provider. To use this filter provider_id is required.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpanPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.credentialing.v_2.get_all()
        """
        _response = self._raw_client.get_all(
            limit=limit,
            page_token=page_token,
            payer_uuid=payer_uuid,
            provider_id=provider_id,
            as_rendering_provider=as_rendering_provider,
            as_contracting_provider=as_contracting_provider,
            request_options=request_options,
        )
        return _response.data

    def delete(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.credentialing.v_2.delete(
            provider_credentialing_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.delete(provider_credentialing_id, request_options=request_options)
        return _response.data

    def update(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        contracting_provider_id: typing.Optional[uuid.UUID] = OMIT,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        contracting_provider_id : typing.Optional[uuid.UUID]
            The ID of the practice location at which the rendering provider is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.credentialing.v_2.update(
            provider_credentialing_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.update(
            provider_credentialing_id,
            contracting_provider_id=contracting_provider_id,
            payer_uuid=payer_uuid,
            start_date=start_date,
            end_date=end_date,
            regions=regions,
            submitted_date=submitted_date,
            payer_loaded_date=payer_loaded_date,
            request_options=request_options,
        )
        return _response.data


class AsyncV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV2Client
        """
        return self._raw_client

    async def create(
        self,
        *,
        rendering_provider_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        regions: Regions,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        rendering_provider_id : uuid.UUID
            The ID of the rendering provider covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the practice location at which the rendering provider is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        regions : Regions
            The states covered by the credentialing span. A span may be national and cover all states.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient
        from candid.resources.commons import Regions_States, State

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.credentialing.v_2.create(
                rendering_provider_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                contracting_provider_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                payer_uuid=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                regions=Regions_States(
                    states=[State.AA, State.AA],
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            rendering_provider_id=rendering_provider_id,
            contracting_provider_id=contracting_provider_id,
            payer_uuid=payer_uuid,
            regions=regions,
            start_date=start_date,
            end_date=end_date,
            submitted_date=submitted_date,
            payer_loaded_date=payer_loaded_date,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.credentialing.v_2.get(
                provider_credentialing_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(provider_credentialing_id, request_options=request_options)
        return _response.data

    async def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        provider_id: typing.Optional[uuid.UUID] = None,
        as_rendering_provider: typing.Optional[bool] = None,
        as_contracting_provider: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpanPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        provider_id : typing.Optional[uuid.UUID]
            Filter to a particular provider. Use in conjunction as_rendering_provider and as_contracting_provider.

        as_rendering_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a rendering provider. To use this filter provider_id is required.

        as_contracting_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a contracting provider. To use this filter provider_id is required.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpanPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.credentialing.v_2.get_all()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_all(
            limit=limit,
            page_token=page_token,
            payer_uuid=payer_uuid,
            provider_id=provider_id,
            as_rendering_provider=as_rendering_provider,
            as_contracting_provider=as_contracting_provider,
            request_options=request_options,
        )
        return _response.data

    async def delete(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.credentialing.v_2.delete(
                provider_credentialing_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(provider_credentialing_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        contracting_provider_id: typing.Optional[uuid.UUID] = OMIT,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProviderCredentialingSpan:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        contracting_provider_id : typing.Optional[uuid.UUID]
            The ID of the practice location at which the rendering provider is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProviderCredentialingSpan

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.credentialing.v_2.update(
                provider_credentialing_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            provider_credentialing_id,
            contracting_provider_id=contracting_provider_id,
            payer_uuid=payer_uuid,
            start_date=start_date,
            end_date=end_date,
            regions=regions,
            submitted_date=submitted_date,
            payer_loaded_date=payer_loaded_date,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .raw_client import AsyncRawV3Client, RawV3Client
from .types.get_exports_response import GetExportsResponse


class V3Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV3Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV3Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV3Client
        """
        return self._raw_client

    def get_exports(
        self, *, start_date: dt.date, end_date: dt.date, request_options: typing.Optional[RequestOptions] = None
    ) -> GetExportsResponse:
        """
        Retrieve CSV-formatted reports on claim submissions and outcomes. This endpoint returns Export objects that contain an
        authenticated URL to a customer's reports with a 2min TTL. The schema for the CSV export can be found [here](https://app.joincandidhealth.com/files/exports_schema.csv).

        **Schema changes:** Changing column order, removing columns, or changing the name of a column is considered a
        [Breaking Change](../../../api-principles/breaking-changes). Adding new columns to the end of the Exports file is not considered a
        Breaking Change and happens periodically. For this reason, it is important that any downstream automation or processes built on top
        of Candid Health's export files be resilient to the addition of new columns at the end of the file.

        **SLA guarantees:** Files for a given date are guaranteed to be available after 3 business days. For example, Friday's file will be
        available by Wednesday at the latest. If file generation is still in progress upon request before 3 business days have passed, the
        caller will receive a 422 response. If the file has already been generated, it will be served. Historic files should be available
        up to 90 days in the past by default. Please email our [Support team](mailto:support@joincandidhealth.com) with any data requests
        outside of these stated guarantees.

        **New Customers:** This endpoint is not enabled by default for new Candid customers. To have this endpoint enabled for your organization,
        please email our [Support team](mailto:support@joincandidhealth.com) with the request.

        Parameters
        ----------
        start_date : dt.date
            Beginning date of claim versions returned in the export, ISO 8601 date e.g. 2019-08-24.
            Must be at least 1 calendar day in the past. Cannot be earlier than 2022-10-07.

        end_date : dt.date
            Ending date of claim versions returned in the export, ISO 8601 date; e.g. 2019-08-24.
            Must be within 30 days of start_date.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetExportsResponse

        Examples
        --------
        import datetime

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.exports.v_3.get_exports(
            start_date=datetime.date.fromisoformat(
                "2023-10-01",
            ),
            end_date=datetime.date.fromisoformat(
                "2023-10-02",
            ),
        )
        """
        _response = self._raw_client.get_exports(
            start_date=start_date, end_date=end_date, request_options=request_options
        )
        return _response.data


class AsyncV3Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV3Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV3Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV3Client
        """
        return self._raw_client

    async def get_exports(
        self, *, start_date: dt.date, end_date: dt.date, request_options: typing.Optional[RequestOptions] = None
    ) -> GetExportsResponse:
        """
        Retrieve CSV-formatted reports on claim submissions and outcomes. This endpoint returns Export objects that contain an
        authenticated URL to a customer's reports with a 2min TTL. The schema for the CSV export can be found [here](https://app.joincandidhealth.com/files/exports_schema.csv).

        **Schema changes:** Changing column order, removing columns, or changing the name of a column is considered a
        [Breaking Change](../../../api-principles/breaking-changes). Adding new columns to the end of the Exports file is not considered a
        Breaking Change and happens periodically. For this reason, it is important that any downstream automation or processes built on top
        of Candid Health's export files be resilient to the addition of new columns at the end of the file.

        **SLA guarantees:** Files for a given date are guaranteed to be available after 3 business days. For example, Friday's file will be
        available by Wednesday at the latest. If file generation is still in progress upon request before 3 business days have passed, the
        caller will receive a 422 response. If the file has already been generated, it will be served. Historic files should be available
        up to 90 days in the past by default. Please email our [Support team](mailto:support@joincandidhealth.com) with any data requests
        outside of these stated guarantees.

        **New Customers:** This endpoint is not enabled by default for new Candid customers. To have this endpoint enabled for your organization,
        please email our [Support team](mailto:support@joincandidhealth.com) with the request.

        Parameters
        ----------
        start_date : dt.date
            Beginning date of claim versions returned in the export, ISO 8601 date e.g. 2019-08-24.
            Must be at least 1 calendar day in the past. Cannot be earlier than 2022-10-07.

        end_date : dt.date
            Ending date of claim versions returned in the export, ISO 8601 date; e.g. 2019-08-24.
            Must be within 30 days of start_date.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetExportsResponse

        Examples
        --------
        import asyncio
        import datetime

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.exports.v_3.get_exports(
                start_date=datetime.date.fromisoformat(
                    "2023-10-01",
                ),
                end_date=datetime.date.fromisoformat(
                    "2023-10-02",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_exports(
            start_date=start_date, end_date=end_date, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .benefit_type import BenefitType
from .coverage_level import CoverageLevel
from .coverage_value_unit import CoverageValueUnit


class CoverageDetails(UniversalBaseModel):
    type: BenefitType
    coverage_level: CoverageLevel = pydantic.Field(alias="coverageLevel")
    unit: CoverageValueUnit
    value: float
    additional_notes: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validations_error import HttpRequestValidationsError
from ....commons.errors.unauthorized_error import UnauthorizedError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.charge_capture_claim_creation_id import ChargeCaptureClaimCreationId
from ....commons.types.charge_capture_id import ChargeCaptureId
from ....commons.types.charge_capture_post_billed_change_id import ChargeCapturePostBilledChangeId
from ....commons.types.encounter_id import EncounterId
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.page_token import PageToken
from ....commons.types.request_validation_error import RequestValidationError
from ....commons.types.sort_direction import SortDirection
from ....commons.types.unauthorized_error_message import UnauthorizedErrorMessage
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from ....encounters.resources.v_4.errors.schema_instance_validation_http_failure import (
    SchemaInstanceValidationHttpFailure,
)
from ....encounters.resources.v_4.types.schema_instance_validation_failure import SchemaInstanceValidationFailure
from .errors.charge_external_id_conflict_error import ChargeExternalIdConflictError
from .types.charge_capture import ChargeCapture
from .types.charge_capture_data import ChargeCaptureData
from .types.charge_capture_page import ChargeCapturePage
from .types.charge_capture_post_billed_change import ChargeCapturePostBilledChange
from .types.charge_capture_sort_field import ChargeCaptureSortField
from .types.charge_capture_status import ChargeCaptureStatus
from .types.charge_external_id_conflict_error_message import ChargeExternalIdConflictErrorMessage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        patient_external_id: str,
        status: ChargeCaptureStatus,
        ehr_source_url: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        patient_external_id : str
            The patient ID from the external EMR platform for the patient

        status : ChargeCaptureStatus
            the status of the charge capture

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return HttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        charge_capture_id: ChargeCaptureId,
        *,
        data: typing.Optional[ChargeCaptureData] = OMIT,
        charge_external_id: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        patient_external_id: typing.Optional[str] = OMIT,
        status: typing.Optional[ChargeCaptureStatus] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        data : typing.Optional[ChargeCaptureData]

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page).
            Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge capture

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapture]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[ChargeCaptureSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        patient_external_id: typing.Optional[str] = None,
        status: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id: typing.Optional[str] = None,
        date_of_service_min: typing.Optional[dt.date] = None,
        date_of_service_max: typing.Optional[dt.date] = None,
        claim_ids: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name: typing.Optional[str] = None,
        primary_payer_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        exclude_charges_linked_to_claims: typing.Optional[bool] = None,
        patient_external_id_ranked_sort: typing.Optional[str] = None,
        status_ranked_sort: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id_ranked_sort: typing.Optional[str] = None,
        date_of_service_min_ranked_sort: typing.Optional[dt.date] = None,
        date_of_service_max_ranked_sort: typing.Optional[dt.date] = None,
        claim_ids_ranked_sort: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids_ranked_sort: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name_ranked_sort: typing.Optional[str] = None,
        primary_payer_ids_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ChargeCapturePage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        sort : typing.Optional[ChargeCaptureSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge captures

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to filter by. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to filter by.

        billing_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        service_facility_name : typing.Optional[str]
            A string to filter by. This will return all charge captures with this service facility name.

        primary_payer_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to filter by. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to filter by. This will return all charge captures with one of the names in this list.

        supervising_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to filter by. This will return all charge captures with one of the names in this list.

        exclude_charges_linked_to_claims : typing.Optional[bool]
            Whether to exclude charge captures which are part of a claim creation.

        patient_external_id_ranked_sort : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status_ranked_sort : typing.Optional[ChargeCaptureStatus]
            The charge capture status to show first

        charge_external_id_ranked_sort : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids_ranked_sort : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to show first. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids_ranked_sort : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to show first.

        billing_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        service_facility_name_ranked_sort : typing.Optional[str]
            A string to show first. This will return all charge captures with this service facility name.

        primary_payer_ids_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to show first. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to show first. This will return all charge captures with one of the names in this list.

        supervising_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to show first. This will return all charge captures with one of the names in this list.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ChargeCapturePage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
                "patient_external_id": patient_external_id,
                "status": status,
                "charge_external_id": charge_external_id,
                "date_of_service_min": str(date_of_service_min) if date_of_service_min is not None else None,
                "date_of_service_max": str(date_of_service_max) if date_of_service_max is not None else None,
                "claim_ids": claim_ids,
                "claim_creation_ids": claim_creation_ids,
                "billing_provider_npis": billing_provider_npis,
                "service_facility_name": service_facility_name,
                "primary_payer_ids": primary_payer_ids,
                "rendering_provider_npis": rendering_provider_npis,
                "rendering_provider_names": rendering_provider_names,
                "supervising_provider_npis": supervising_provider_npis,
                "supervising_provider_names": supervising_provider_names,
                "exclude_charges_linked_to_claims": exclude_charges_linked_to_claims,
                "patient_external_id_ranked_sort": patient_external_id_ranked_sort,
                "status_ranked_sort": status_ranked_sort,
                "charge_external_id_ranked_sort": charge_external_id_ranked_sort,
                "date_of_service_min_ranked_sort": str(date_of_service_min_ranked_sort)
                if date_of_service_min_ranked_sort is not None
                else None,
                "date_of_service_max_ranked_sort": str(date_of_service_max_ranked_sort)
                if date_of_service_max_ranked_sort is not None
                else None,
                "claim_ids_ranked_sort": claim_ids_ranked_sort,
                "claim_creation_ids_ranked_sort": claim_creation_ids_ranked_sort,
                "billing_provider_npis_ranked_sort": billing_provider_npis_ranked_sort,
                "service_facility_name_ranked_sort": service_facility_name_ranked_sort,
                "primary_payer_ids_ranked_sort": primary_payer_ids_ranked_sort,
                "rendering_provider_npis_ranked_sort": rendering_provider_npis_ranked_sort,
                "rendering_provider_names_ranked_sort": rendering_provider_names_ranked_sort,
                "supervising_provider_npis_ranked_sort": supervising_provider_npis_ranked_sort,
                "supervising_provider_names_ranked_sort": supervising_provider_names_ranked_sort,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapturePage,
                parse_obj_as(
                    type_=ChargeCapturePage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_post_billed_changes(
        self,
        *,
        charge_capture_change_ids: typing.Sequence[ChargeCapturePostBilledChangeId],
        resolved: bool,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[ChargeCapturePostBilledChange]]:
        """
        Parameters
        ----------
        charge_capture_change_ids : typing.Sequence[ChargeCapturePostBilledChangeId]
            A list of UUIDs corresponding to ChargeCapturePostBilledChanges.
            All of the charges sent will be marked as resolved

        resolved : bool
            Whether the change has been resolved. If true, the change will be marked as resolved.
            If false, the change will be marked as unresolved.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[ChargeCapturePostBilledChange]]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/changes/",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "charge_capture_change_ids": charge_capture_change_ids,
                "resolved": resolved,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[ChargeCapturePostBilledChange],
                parse_obj_as(
                    type_=typing.List[ChargeCapturePostBilledChange],  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        data: ChargeCaptureData,
        charge_external_id: str,
        patient_external_id: str,
        status: ChargeCaptureStatus,
        ehr_source_url: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        data : ChargeCaptureData
            Charge Capture data contains all the fields needed to create an encounter, but listed as optional. Candid will use this data when attempting to bundle multiple Charge Captures into a single encounter.

        charge_external_id : str
            A client-specified unique ID to associate with this encounter; for example, your internal encounter ID or a Dr. Chrono encounter ID. This field should not contain PHI.

        patient_external_id : str
            The patient ID from the external EMR platform for the patient

        status : ChargeCaptureStatus
            the status of the charge capture

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page). Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "ChargeExternalIdConflictError":
                raise ChargeExternalIdConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        ChargeExternalIdConflictErrorMessage,
                        parse_obj_as(
                            type_=ChargeExternalIdConflictErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return AsyncHttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        charge_capture_id: ChargeCaptureId,
        *,
        data: typing.Optional[ChargeCaptureData] = OMIT,
        charge_external_id: typing.Optional[str] = OMIT,
        ehr_source_url: typing.Optional[str] = OMIT,
        patient_external_id: typing.Optional[str] = OMIT,
        status: typing.Optional[ChargeCaptureStatus] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        data : typing.Optional[ChargeCaptureData]

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        ehr_source_url : typing.Optional[str]
            External URL reference that links to Charge Capture details within the external system (e.g. the EHR visit page).
            Send full URL format for the external link (e.g. https://emr_charge_capture_url.com/123).

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge capture

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "data": data,
                "charge_external_id": charge_external_id,
                "ehr_source_url": ehr_source_url,
                "patient_external_id": patient_external_id,
                "status": status,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, charge_capture_id: ChargeCaptureId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ChargeCapture]:
        """
        Parameters
        ----------
        charge_capture_id : ChargeCaptureId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapture]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/charge_captures/v1/{jsonable_encoder(charge_capture_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapture,
                parse_obj_as(
                    type_=ChargeCapture,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[ChargeCaptureSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        patient_external_id: typing.Optional[str] = None,
        status: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id: typing.Optional[str] = None,
        date_of_service_min: typing.Optional[dt.date] = None,
        date_of_service_max: typing.Optional[dt.date] = None,
        claim_ids: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name: typing.Optional[str] = None,
        primary_payer_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        exclude_charges_linked_to_claims: typing.Optional[bool] = None,
        patient_external_id_ranked_sort: typing.Optional[str] = None,
        status_ranked_sort: typing.Optional[ChargeCaptureStatus] = None,
        charge_external_id_ranked_sort: typing.Optional[str] = None,
        date_of_service_min_ranked_sort: typing.Optional[dt.date] = None,
        date_of_service_max_ranked_sort: typing.Optional[dt.date] = None,
        claim_ids_ranked_sort: typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]] = None,
        claim_creation_ids_ranked_sort: typing.Optional[
            typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]
        ] = None,
        billing_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        service_facility_name_ranked_sort: typing.Optional[str] = None,
        primary_payer_ids_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        rendering_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_npis_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        supervising_provider_names_ranked_sort: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ChargeCapturePage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        sort : typing.Optional[ChargeCaptureSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        patient_external_id : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status : typing.Optional[ChargeCaptureStatus]
            the status of the charge captures

        charge_external_id : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to filter by. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to filter by.

        billing_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        service_facility_name : typing.Optional[str]
            A string to filter by. This will return all charge captures with this service facility name.

        primary_payer_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to filter by. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to filter by. This will return all charge captures with one of the names in this list.

        supervising_provider_npis : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to filter by. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to filter by. This will return all charge captures with one of the names in this list.

        exclude_charges_linked_to_claims : typing.Optional[bool]
            Whether to exclude charge captures which are part of a claim creation.

        patient_external_id_ranked_sort : typing.Optional[str]
            The patient ID from the external EMR platform for the patient

        status_ranked_sort : typing.Optional[ChargeCaptureStatus]
            The charge capture status to show first

        charge_external_id_ranked_sort : typing.Optional[str]
            A client-specified unique ID to associate with this encounter;
            for example, your internal encounter ID or a Dr. Chrono encounter ID.
            This field should not contain PHI.

        date_of_service_min_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        date_of_service_max_ranked_sort : typing.Optional[dt.date]
            Date formatted as YYYY-MM-DD; eg: 2019-08-24.
            This date must be the local date in the timezone where the service occurred.

        claim_ids_ranked_sort : typing.Optional[typing.Union[EncounterId, typing.Sequence[EncounterId]]]
            A list of claim IDs to show first. This will return all charge captures that have a resulting claim with one of the IDs in this list.

        claim_creation_ids_ranked_sort : typing.Optional[typing.Union[ChargeCaptureClaimCreationId, typing.Sequence[ChargeCaptureClaimCreationId]]]
            A list of Claim Creation IDs to show first.

        billing_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of billing provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        service_facility_name_ranked_sort : typing.Optional[str]
            A string to show first. This will return all charge captures with this service facility name.

        primary_payer_ids_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of primary payer IDs to show first. This will return all charge captures with one of the primary payer IDs in this list.

        rendering_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        rendering_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of rendering provider names to show first. This will return all charge captures with one of the names in this list.

        supervising_provider_npis_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider NPIs to show first. This will return all charge captures with one of the NPIs in this list.

        supervising_provider_names_ranked_sort : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A list of supervising provider names to show first. This will return all charge captures with one of the names in this list.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ChargeCapturePage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
                "patient_external_id": patient_external_id,
                "status": status,
                "charge_external_id": charge_external_id,
                "date_of_service_min": str(date_of_service_min) if date_of_service_min is not None else None,
                "date_of_service_max": str(date_of_service_max) if date_of_service_max is not None else None,
                "claim_ids": claim_ids,
                "claim_creation_ids": claim_creation_ids,
                "billing_provider_npis": billing_provider_npis,
                "service_facility_name": service_facility_name,
                "primary_payer_ids": primary_payer_ids,
                "rendering_provider_npis": rendering_provider_npis,
                "rendering_provider_names": rendering_provider_names,
                "supervising_provider_npis": supervising_provider_npis,
                "supervising_provider_names": supervising_provider_names,
                "exclude_charges_linked_to_claims": exclude_charges_linked_to_claims,
                "patient_external_id_ranked_sort": patient_external_id_ranked_sort,
                "status_ranked_sort": status_ranked_sort,
                "charge_external_id_ranked_sort": charge_external_id_ranked_sort,
                "date_of_service_min_ranked_sort": str(date_of_service_min_ranked_sort)
                if date_of_service_min_ranked_sort is not None
                else None,
                "date_of_service_max_ranked_sort": str(date_of_service_max_ranked_sort)
                if date_of_service_max_ranked_sort is not None
                else None,
                "claim_ids_ranked_sort": claim_ids_ranked_sort,
                "claim_creation_ids_ranked_sort": claim_creation_ids_ranked_sort,
                "billing_provider_npis_ranked_sort": billing_provider_npis_ranked_sort,
                "service_facility_name_ranked_sort": service_facility_name_ranked_sort,
                "primary_payer_ids_ranked_sort": primary_payer_ids_ranked_sort,
                "rendering_provider_npis_ranked_sort": rendering_provider_npis_ranked_sort,
                "rendering_provider_names_ranked_sort": rendering_provider_names_ranked_sort,
                "supervising_provider_npis_ranked_sort": supervising_provider_npis_ranked_sort,
                "supervising_provider_names_ranked_sort": supervising_provider_names_ranked_sort,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ChargeCapturePage,
                parse_obj_as(
                    type_=ChargeCapturePage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_post_billed_changes(
        self,
        *,
        charge_capture_change_ids: typing.Sequence[ChargeCapturePostBilledChangeId],
        resolved: bool,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[ChargeCapturePostBilledChange]]:
        """
        Parameters
        ----------
        charge_capture_change_ids : typing.Sequence[ChargeCapturePostBilledChangeId]
            A list of UUIDs corresponding to ChargeCapturePostBilledChanges.
            All of the charges sent will be marked as resolved

        resolved : bool
            Whether the change has been resolved. If true, the change will be marked as resolved.
            If false, the change will be marked as unresolved.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[ChargeCapturePostBilledChange]]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/charge_captures/v1/changes/",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "charge_capture_change_ids": charge_capture_change_ids,
                "resolved": resolved,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[ChargeCapturePostBilledChange],
                parse_obj_as(
                    type_=typing.List[ChargeCapturePostBilledChange],  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .encounter_has_existing_guarantor_error_type import EncounterHasExistingGuarantorErrorType
from .guarantor import Guarantor
from .guarantor_base import GuarantorBase
from .guarantor_create import GuarantorCreate
from .guarantor_id import GuarantorId
from .guarantor_update import GuarantorUpdate

__all__ = [
    "EncounterHasExistingGuarantorErrorType",
    "Guarantor",
    "GuarantorBase",
    "GuarantorCreate",
    "GuarantorId",
    "GuarantorUpdate",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.insurance_type_code import InsuranceTypeCode


class InsuranceTypes_AllApply(UniversalBaseModel):
    type: typing.Literal["allApply"] = "allApply"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class InsuranceTypes_NoneApply(UniversalBaseModel):
    type: typing.Literal["noneApply"] = "noneApply"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class InsuranceTypes_TheseApply(UniversalBaseModel):
    value: typing.Set[InsuranceTypeCode]
    type: typing.Literal["theseApply"] = "theseApply"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


InsuranceTypes = typing.Union[InsuranceTypes_AllApply, InsuranceTypes_NoneApply, InsuranceTypes_TheseApply]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AppointmentListItem,
    AppointmentListPage,
    FilterQueryString,
    PatientListItem,
    PatientListPage,
    SortFieldString,
)

__all__ = [
    "AppointmentListItem",
    "AppointmentListPage",
    "FilterQueryString",
    "PatientListItem",
    "PatientListPage",
    "SortFieldString",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....payers.resources.v_3.types.payer_uuid import PayerUuid
from .insurance_type import InsuranceType


class ExpectedNetworkStatusSubscriberInformation(UniversalBaseModel):
    payer_uuid: PayerUuid = pydantic.Field()
    """
    The UUID that corresponds with the payer on the patient’s insurance card
    """

    member_id: str = pydantic.Field()
    """
    The member_id on the patient’s insurance card
    """

    insurance_type: InsuranceType = pydantic.Field()
    """
    The insurance information on the patient's insurance card
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from ....commons.types.page_token import PageToken
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.external_payment_account_config_page import ExternalPaymentAccountConfigPage


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExternalPaymentAccountConfigPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExternalPaymentAccountConfigPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.external_payment_account_config.v_1.get_multi()
        """
        _response = self._raw_client.get_multi(limit=limit, page_token=page_token, request_options=request_options)
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExternalPaymentAccountConfigPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExternalPaymentAccountConfigPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.external_payment_account_config.v_1.get_multi()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_multi(
            limit=limit, page_token=page_token, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .schema_validation_http_failure import SchemaValidationHttpFailure

__all__ = ["SchemaValidationHttpFailure"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .additional_payer_information import AdditionalPayerInformation
from .address import Address
from .address_use import AddressUse
from .appointment_id import AppointmentId
from .base_model import BaseModel
from .canonical_clinical_trial_association import CanonicalClinicalTrialAssociation
from .canonical_clinical_trial_id import CanonicalClinicalTrialId
from .canonical_non_insurance_payer_association import CanonicalNonInsurancePayerAssociation
from .canonical_non_insurance_payer_id import CanonicalNonInsurancePayerId
from .canonical_provider_id import CanonicalProviderId
from .contact_point import ContactPoint
from .contact_point_use import ContactPointUse
from .coverage_id import CoverageId
from .disability_status import DisabilityStatus
from .error_base_4_xx import ErrorBase4Xx
from .ethnicity import Ethnicity
from .external_identifier import ExternalIdentifier
from .external_provider import ExternalProvider
from .external_provider_type import ExternalProviderType
from .gender import Gender
from .human_name import HumanName
from .name_use import NameUse
from .note_id import NoteId
from .organization_id import OrganizationId
from .page_token import PageToken
from .patient_id import PatientId
from .payer_id import PayerId
from .payer_plan_group_id import PayerPlanGroupId
from .period import Period
from .race import Race
from .relationship import Relationship
from .resource_page import ResourcePage
from .sex import Sex
from .sexual_orientation import SexualOrientation
from .sort_direction import SortDirection
from .tag_id import TagId
from .user_id import UserId
from .version_conflict_error_body import VersionConflictErrorBody

__all__ = [
    "AdditionalPayerInformation",
    "Address",
    "AddressUse",
    "AppointmentId",
    "BaseModel",
    "CanonicalClinicalTrialAssociation",
    "CanonicalClinicalTrialId",
    "CanonicalNonInsurancePayerAssociation",
    "CanonicalNonInsurancePayerId",
    "CanonicalProviderId",
    "ContactPoint",
    "ContactPointUse",
    "CoverageId",
    "DisabilityStatus",
    "ErrorBase4Xx",
    "Ethnicity",
    "ExternalIdentifier",
    "ExternalProvider",
    "ExternalProviderType",
    "Gender",
    "HumanName",
    "NameUse",
    "NoteId",
    "OrganizationId",
    "PageToken",
    "PatientId",
    "PayerId",
    "PayerPlanGroupId",
    "Period",
    "Race",
    "Relationship",
    "ResourcePage",
    "Sex",
    "SexualOrientation",
    "SortDirection",
    "TagId",
    "UserId",
    "VersionConflictErrorBody",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    CreateWriteOffsResponse,
    InsuranceWriteOff,
    InsuranceWriteOffCreate,
    InsuranceWriteOffReason,
    InsuranceWriteOffTarget,
    InsuranceWriteOffTarget_BillingProviderId,
    InsuranceWriteOffTarget_ClaimId,
    InsuranceWriteOffTarget_ServiceLineId,
    NonInsurancePayerWriteOff,
    NonInsurancePayerWriteOffCreate,
    PatientWriteOff,
    PatientWriteOffCreate,
    PatientWriteOffReason,
    WriteOff,
    WriteOffCreate,
    WriteOffCreate_Insurance,
    WriteOffCreate_NonInsurancePayer,
    WriteOffCreate_Patient,
    WriteOffId,
    WriteOffSortField,
    WriteOff_Insurance,
    WriteOff_NonInsurancePayer,
    WriteOff_Patient,
    WriteOffsPage,
)

__all__ = [
    "CreateWriteOffsResponse",
    "InsuranceWriteOff",
    "InsuranceWriteOffCreate",
    "InsuranceWriteOffReason",
    "InsuranceWriteOffTarget",
    "InsuranceWriteOffTarget_BillingProviderId",
    "InsuranceWriteOffTarget_ClaimId",
    "InsuranceWriteOffTarget_ServiceLineId",
    "NonInsurancePayerWriteOff",
    "NonInsurancePayerWriteOffCreate",
    "PatientWriteOff",
    "PatientWriteOffCreate",
    "PatientWriteOffReason",
    "WriteOff",
    "WriteOffCreate",
    "WriteOffCreate_Insurance",
    "WriteOffCreate_NonInsurancePayer",
    "WriteOffCreate_Patient",
    "WriteOffId",
    "WriteOffSortField",
    "WriteOff_Insurance",
    "WriteOff_NonInsurancePayer",
    "WriteOff_Patient",
    "WriteOffsPage",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ChargeCaptureClaimCreationSummary(UniversalBaseModel):
    charge_capture_charges_not_linked_to_claims_count: int = pydantic.Field()
    """
    The count of charge captures which are not part of a Claim Creation.
    """

    charge_capture_claim_creations_not_started_count: int = pydantic.Field()
    """
    The count of charge capture claim_creations that have a Claim Creation status of NOT_STARTED.
    """

    charge_capture_held_claim_creations_count: int = pydantic.Field()
    """
    The count of charge capture claim_creations that have a Claim Creation status of HELD.
    """

    charge_capture_claim_creations_in_error_count: int = pydantic.Field()
    """
    The count of charge capture claim_creations that have a Claim Creation status of IN_ERROR.
    """

    charge_capture_unresolved_change_count: int = pydantic.Field()
    """
    The number of ChargeCapturePostBilledChange items that are unresolved.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .claim_frequency_type_code import ClaimFrequencyTypeCode
from .claim_submission_record_create import ClaimSubmissionRecordCreate
from .external_claim_submission_create import ExternalClaimSubmissionCreate

__all__ = ["ClaimFrequencyTypeCode", "ClaimSubmissionRecordCreate", "ExternalClaimSubmissionCreate"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....charge_capture.resources.v_1.types.charge_capture_data import ChargeCaptureData
from .....charge_capture.resources.v_1.types.charge_capture_error import ChargeCaptureError
from .....commons.types.charge_capture_claim_creation_id import ChargeCaptureClaimCreationId
from .....commons.types.encounter_id import EncounterId
from .charge_capture_claim_creation_status import ChargeCaptureClaimCreationStatus


class ChargeCaptureClaimCreation(UniversalBaseModel):
    id: ChargeCaptureClaimCreationId
    created_encounter_id: typing.Optional[EncounterId] = None
    status: ChargeCaptureClaimCreationStatus = pydantic.Field()
    """
    Status of the Claim Creation, Successful means that the Claim Creation created a corresponding Claim
    """

    characteristics: typing.Dict[str, typing.Optional[typing.Optional[typing.Any]]] = pydantic.Field()
    """
    A dictionary of characteristics that are used to group charge captures together based on the bundling configuration.
    Example: {"service_facility.npi": "99999999", "date_of_service": "2023-01-01"}
    """

    errors: typing.List[ChargeCaptureError] = pydantic.Field()
    """
    All errors that were found when the Claim was attempted to be created.
    Errors can correspond to the Claim Creation as a whole or specific underlying Charge Captures.
    """

    encounter_creation_input: typing.Optional[ChargeCaptureData] = pydantic.Field(default=None)
    """
    If a ChargeCaptureBundle attempts creation, this is the input that was created from the underlying charges and used to attempt encounter creation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from .era_base import EraBase
from .era_id import EraId


class Era(EraBase):
    """
    Examples
    --------
    import uuid

    from candid.resources.era import Era

    Era(
        era_id=uuid.UUID(
            "4d844ef1-2253-43cd-a4f1-6db7e65cb54b",
        ),
        check_number="CHK12345",
        check_date="2023-10-12",
    )
    """

    era_id: EraId

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .clinical_trial import ClinicalTrial
from .clinical_trial_phase import ClinicalTrialPhase
from .mutable_clinical_trial import MutableClinicalTrial

__all__ = ["ClinicalTrial", "ClinicalTrialPhase", "MutableClinicalTrial"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.resource_page import ResourcePage
from .payer import Payer


class PayerPage(ResourcePage):
    """
    Examples
    --------
    import uuid

    from candid.resources.payers.resources.v_3 import Payer, PayerPage

    PayerPage(
        items=[
            Payer(
                payer_uuid=uuid.UUID(
                    "a6431fd2-0712-4714-b1b1-dd094daf9f42",
                ),
                payer_id="12345",
                payer_name="Payer Name",
                availity_payer_name="Availity Payer Name",
                availity_claims_payer_id="54321",
                availity_eligibility_id="54321",
                availity_remittance_payer_id="54321",
            )
        ],
    )
    """

    items: typing.List[Payer]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from .raw_client import AsyncRawServiceFacilityClient, RawServiceFacilityClient
from .types.encounter_service_facility import EncounterServiceFacility
from .types.encounter_service_facility_update import EncounterServiceFacilityUpdate
from .types.service_facility_id import ServiceFacilityId

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ServiceFacilityClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawServiceFacilityClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawServiceFacilityClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawServiceFacilityClient
        """
        return self._raw_client

    def update(
        self,
        service_facility_id: ServiceFacilityId,
        *,
        request: EncounterServiceFacilityUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterServiceFacility:
        """
        Parameters
        ----------
        service_facility_id : ServiceFacilityId

        request : EncounterServiceFacilityUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterServiceFacility

        Examples
        --------
        import uuid

        from candid import CandidApiClient
        from candid.resources.service_facility import EncounterServiceFacilityUpdate

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.service_facility.update(
            service_facility_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=EncounterServiceFacilityUpdate(),
        )
        """
        _response = self._raw_client.update(service_facility_id, request=request, request_options=request_options)
        return _response.data


class AsyncServiceFacilityClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawServiceFacilityClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawServiceFacilityClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawServiceFacilityClient
        """
        return self._raw_client

    async def update(
        self,
        service_facility_id: ServiceFacilityId,
        *,
        request: EncounterServiceFacilityUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EncounterServiceFacility:
        """
        Parameters
        ----------
        service_facility_id : ServiceFacilityId

        request : EncounterServiceFacilityUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EncounterServiceFacility

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient
        from candid.resources.service_facility import EncounterServiceFacilityUpdate

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.service_facility.update(
                service_facility_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=EncounterServiceFacilityUpdate(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(service_facility_id, request=request, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...commons.types.date_range_optional_end import DateRangeOptionalEnd
from ...commons.types.removable_date_range_optional_end import RemovableDateRangeOptionalEnd
from .identifier_code import IdentifierCode
from .identifier_id import IdentifierId
from .identifier_value import IdentifierValue


class UpdatableIdentifier_Add(UniversalBaseModel):
    type: typing.Literal["add"] = "add"
    period: typing.Optional[DateRangeOptionalEnd] = None
    identifier_code: IdentifierCode
    identifier_value: IdentifierValue

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class UpdatableIdentifier_Update(UniversalBaseModel):
    type: typing.Literal["update"] = "update"
    identifier_id: IdentifierId
    identifier_code: typing.Optional[IdentifierCode] = None
    identifier_value: typing.Optional[IdentifierValue] = None
    period: typing.Optional[RemovableDateRangeOptionalEnd] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class UpdatableIdentifier_Remove(UniversalBaseModel):
    value: IdentifierId
    type: typing.Literal["remove"] = "remove"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


UpdatableIdentifier = typing.Union[UpdatableIdentifier_Add, UpdatableIdentifier_Update, UpdatableIdentifier_Remove]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.facility_type_code import FacilityTypeCode
from .....commons.types.street_address_short_zip import StreetAddressShortZip
from .....organization_providers.resources.v_2.types.organization_provider_id import OrganizationProviderId
from .....organization_service_facilities.resources.v_2.types.organization_service_facility_id import (
    OrganizationServiceFacilityId,
)
from .expected_network_status_subscriber_information import ExpectedNetworkStatusSubscriberInformation
from .service_type import ServiceType


class ExpectedNetworkStatusRequestV2(UniversalBaseModel):
    service_type: ServiceType = pydantic.Field()
    """
    For some payers, payer routing depends on whether the rendered service qualifies as a behavioral health visit
    (e.g. Blue Shield of California routes to Magellan for behavioral health visits).
    
    For post appointment payer routing, Candid uses a CPT code list to determine whether the appointment qualifies as a
    behavioral health visit
    (see “Inputs: Service Type” in the appendix for list of qualifying CPT codes and behavioral health routing logic).
    Since CPT codes are not available pre-appointment, the service type input is used to determine whether the appointment is expected
    to qualify as behavioral health.
    """

    place_of_service_code: FacilityTypeCode = pydantic.Field()
    """
    Expected place of service
    """

    subscriber_information: ExpectedNetworkStatusSubscriberInformation = pydantic.Field()
    """
    Information present on the patient's insurance card
    """

    patient_address: StreetAddressShortZip
    billing_provider_id: OrganizationProviderId
    organization_service_facility_id: OrganizationServiceFacilityId = pydantic.Field()
    """
    The id of the service facility where the appointment will be rendered
    """

    date_of_service: dt.date = pydantic.Field()
    """
    Expected date of service
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.street_address_long_zip import StreetAddressLongZip
from .payer_uuid import PayerUuid


class Payer(UniversalBaseModel):
    """
    Examples
    --------
    import uuid

    from candid.resources.payers.resources.v_3 import Payer

    Payer(
        payer_uuid=uuid.UUID(
            "a6431fd2-0712-4714-b1b1-dd094daf9f42",
        ),
        payer_id="12345",
        payer_name="Payer Name",
        availity_payer_name="Availity Payer Name",
        availity_claims_payer_id="54321",
        availity_eligibility_id="54321",
        availity_remittance_payer_id="54321",
    )
    """

    payer_uuid: PayerUuid = pydantic.Field()
    """
    Auto-generated ID set on creation.
    """

    payer_id: str = pydantic.Field()
    """
    The primary national payer ID of the payer.
    """

    payer_name: str = pydantic.Field()
    """
    The primary display name of the payer.
    """

    availity_payer_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the payer as it appears in Availity.
    """

    availity_claims_payer_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the payer as it appears in Availity.
    """

    availity_eligibility_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The eligibility ID of the payer as it appears in Availity.
    """

    availity_remittance_payer_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The remittance ID of the payer as it appears in Availity.
    """

    street_address: typing.Optional[StreetAddressLongZip] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class FacilityTypeCode(str, enum.Enum):
    """
    Box 24B on the CMS-1500 claim form. Line-level place of service is not currently supported.
    02 for telemedicine, 11 for in-person. Full list here:
    https://www.cms.gov/Medicare/Coding/place-of-service-codes/Place_of_Service_Code_Set
    """

    PHARMACY = "01"
    """
    Pharmacy
    """

    TELEHEALTH = "02"
    """
    Telehealth
    """

    SCHOOL = "03"
    """
    School
    """

    HOMELESS_SHELTER = "04"
    """
    Homeless Shelter
    """

    INDIAN_HEALTH_SERVICE_FREE_STANDING = "05"
    """
    Indian Health Service (Free Standing)
    """

    INDIAN_HEALTH_SERVICE_PROVIDER_BASED = "06"
    """
    Indian Health Service (Provider Based)
    """

    TRIBAL_FREE_STANDING = "07"
    """
    Tribal Free Standing
    """

    TRIBAL_PROVIDER_BASED = "08"
    """
    Tribal Provider Based
    """

    PRISON_OR_CORRECTIONAL_FACILITY = "09"
    """
    Prison or Correctional Facility
    """

    TELEHEALTH_PATIENT_HOME = "10"
    """
    Telehealth Patient Home
    """

    OFFICE = "11"
    """
    Office
    """

    HOME = "12"
    """
    Home
    """

    ASSISTED_LIVING_FACILITY = "13"
    """
    Assisted Living Facility
    """

    GROUP_HOME = "14"
    """
    Group Home
    """

    MOBILE_UNIT = "15"
    """
    Mobile Unit
    """

    TEMPORARY_LODGING = "16"
    """
    Temporary Lodging
    """

    WALK_IN_RETAIL_HEALTH_CLINIC = "17"
    """
    Walk-in Retail Health Clinic
    """

    PLACE_OF_EMPLOYMENT_WORKSITE = "18"
    """
    Place of Employment Worksite
    """

    OFF_CAMPUS_OUTPATIENT_HOSPITAL = "19"
    """
    Off Campus Outpatient Hospital
    """

    URGENT_CARE_FACILITY = "20"
    """
    Urgent Care Facility
    """

    INPATIENT_HOSPITAL = "21"
    """
    Inpatient Hospital
    """

    OUTPATIENT_HOSPITAL = "22"
    """
    Outpatient Hospital
    """

    EMERGENCY_ROOM_HOSPITAL = "23"
    """
    Emergency Room Hospital
    """

    AMBULATORY_SURGICAL_CENTER = "24"
    """
    Ambulatory Surgical Center
    """

    BIRTHING_CENTER = "25"
    """
    Birthing Center
    """

    MILITARY_TREATMENT_FACILITY = "26"
    """
    Military Treatment Facility
    """

    SKILLED_NURSING_FACILITY = "31"
    """
    Skilled Nursing Facility
    """

    NURSING_FACILITY = "32"
    """
    Nursing Facility
    """

    CUSTODIAL_CARE_FACILITY = "33"
    """
    Custodial Care Facility
    """

    HOSPICE = "34"
    """
    Hospice
    """

    AMBULANCE_LAND = "41"
    """
    Ambulance (Land)
    """

    AMBULANCE_AIR_OR_WATER = "42"
    """
    Ambulance (Air or Water)
    """

    INDEPENDENT_CLINIC = "49"
    """
    Independent Clinic
    """

    FEDERALLY_QUALIFIED_HEALTH_CENTER = "50"
    """
    Federally Qualified Health Center
    """

    INPATIENT_PSYCHIATRIC_FACILITY = "51"
    """
    Inpatient Psychiatric Facility
    """

    PSYCHIATRIC_FACILITY_PARTIAL_HOSPITALIZATION = "52"
    """
    Psychiatric Facility (Partial Hospitalization)
    """

    COMMUNITY_MENTAL_HEALTH_CENTER = "53"
    """
    Community Mental Health Center
    """

    INTERMEDIATE_CARE_FACILITY_MENTALLY_RETARDED = "54"
    """
    Intermediate Care Facility/Individuals with Intellectual Disabilities
    """

    RESIDENTIAL_SUBSTANCE_ABUSE_TREATMENT_FACILITY = "55"
    """
    Residential Substance Abuse Treatment Facility
    """

    PSYCHIATRIC_RESIDENTIAL_TREATMENT_CENTER = "56"
    """
    Psychiatric Residential Treatment Center
    """

    NON_RESIDENTIAL_SUBSTANCE_ABUSE_TREATMENT_FACILITY = "57"
    """
    Non-residential Substance Abuse Treatment Facility
    """

    NON_RESIDENTIAL_OPIOID_TREATMENT_FACILITY = "58"
    """
    Non-residential Opioid Treatment Facility
    """

    MASS_IMMUNIZATION_CENTER = "60"
    """
    Mass Immunization Center
    """

    COMPREHENSIVE_INPATIENT_REHABILITATION_FACILITY = "61"
    """
    Comprehensive Inpatient Rehabilitation Facility
    """

    COMPREHENSIVE_OUTPATIENT_REHABILITATION_FACILITY = "62"
    """
    Comprehensive Outpatient Rehabilitation Facility
    """

    END_STAGE_RENAL_DISEASE_TREATMENT_FACILITY = "65"
    """
    End Stage Renal Disease Treatment Facility
    """

    STATE_OR_LOCAL_PUBLIC_HEALTH_CLINIC = "71"
    """
    State or Local Public Health Clinic
    """

    RURAL_HEALTH_CLINIC = "72"
    """
    Rural Health Clinic
    """

    INDEPENDENT_LABORATORY = "81"
    """
    Independent Laboratory
    """

    OTHER_UNLISTED_FACILITY = "99"
    """
    Other Unlisted Facility
    """

    _UNKNOWN = "__FACILITYTYPECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "FacilityTypeCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        pharmacy: typing.Callable[[], T_Result],
        telehealth: typing.Callable[[], T_Result],
        school: typing.Callable[[], T_Result],
        homeless_shelter: typing.Callable[[], T_Result],
        indian_health_service_free_standing: typing.Callable[[], T_Result],
        indian_health_service_provider_based: typing.Callable[[], T_Result],
        tribal_free_standing: typing.Callable[[], T_Result],
        tribal_provider_based: typing.Callable[[], T_Result],
        prison_or_correctional_facility: typing.Callable[[], T_Result],
        telehealth_patient_home: typing.Callable[[], T_Result],
        office: typing.Callable[[], T_Result],
        home: typing.Callable[[], T_Result],
        assisted_living_facility: typing.Callable[[], T_Result],
        group_home: typing.Callable[[], T_Result],
        mobile_unit: typing.Callable[[], T_Result],
        temporary_lodging: typing.Callable[[], T_Result],
        walk_in_retail_health_clinic: typing.Callable[[], T_Result],
        place_of_employment_worksite: typing.Callable[[], T_Result],
        off_campus_outpatient_hospital: typing.Callable[[], T_Result],
        urgent_care_facility: typing.Callable[[], T_Result],
        inpatient_hospital: typing.Callable[[], T_Result],
        outpatient_hospital: typing.Callable[[], T_Result],
        emergency_room_hospital: typing.Callable[[], T_Result],
        ambulatory_surgical_center: typing.Callable[[], T_Result],
        birthing_center: typing.Callable[[], T_Result],
        military_treatment_facility: typing.Callable[[], T_Result],
        skilled_nursing_facility: typing.Callable[[], T_Result],
        nursing_facility: typing.Callable[[], T_Result],
        custodial_care_facility: typing.Callable[[], T_Result],
        hospice: typing.Callable[[], T_Result],
        ambulance_land: typing.Callable[[], T_Result],
        ambulance_air_or_water: typing.Callable[[], T_Result],
        independent_clinic: typing.Callable[[], T_Result],
        federally_qualified_health_center: typing.Callable[[], T_Result],
        inpatient_psychiatric_facility: typing.Callable[[], T_Result],
        psychiatric_facility_partial_hospitalization: typing.Callable[[], T_Result],
        community_mental_health_center: typing.Callable[[], T_Result],
        intermediate_care_facility_mentally_retarded: typing.Callable[[], T_Result],
        residential_substance_abuse_treatment_facility: typing.Callable[[], T_Result],
        psychiatric_residential_treatment_center: typing.Callable[[], T_Result],
        non_residential_substance_abuse_treatment_facility: typing.Callable[[], T_Result],
        non_residential_opioid_treatment_facility: typing.Callable[[], T_Result],
        mass_immunization_center: typing.Callable[[], T_Result],
        comprehensive_inpatient_rehabilitation_facility: typing.Callable[[], T_Result],
        comprehensive_outpatient_rehabilitation_facility: typing.Callable[[], T_Result],
        end_stage_renal_disease_treatment_facility: typing.Callable[[], T_Result],
        state_or_local_public_health_clinic: typing.Callable[[], T_Result],
        rural_health_clinic: typing.Callable[[], T_Result],
        independent_laboratory: typing.Callable[[], T_Result],
        other_unlisted_facility: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is FacilityTypeCode.PHARMACY:
            return pharmacy()
        if self is FacilityTypeCode.TELEHEALTH:
            return telehealth()
        if self is FacilityTypeCode.SCHOOL:
            return school()
        if self is FacilityTypeCode.HOMELESS_SHELTER:
            return homeless_shelter()
        if self is FacilityTypeCode.INDIAN_HEALTH_SERVICE_FREE_STANDING:
            return indian_health_service_free_standing()
        if self is FacilityTypeCode.INDIAN_HEALTH_SERVICE_PROVIDER_BASED:
            return indian_health_service_provider_based()
        if self is FacilityTypeCode.TRIBAL_FREE_STANDING:
            return tribal_free_standing()
        if self is FacilityTypeCode.TRIBAL_PROVIDER_BASED:
            return tribal_provider_based()
        if self is FacilityTypeCode.PRISON_OR_CORRECTIONAL_FACILITY:
            return prison_or_correctional_facility()
        if self is FacilityTypeCode.TELEHEALTH_PATIENT_HOME:
            return telehealth_patient_home()
        if self is FacilityTypeCode.OFFICE:
            return office()
        if self is FacilityTypeCode.HOME:
            return home()
        if self is FacilityTypeCode.ASSISTED_LIVING_FACILITY:
            return assisted_living_facility()
        if self is FacilityTypeCode.GROUP_HOME:
            return group_home()
        if self is FacilityTypeCode.MOBILE_UNIT:
            return mobile_unit()
        if self is FacilityTypeCode.TEMPORARY_LODGING:
            return temporary_lodging()
        if self is FacilityTypeCode.WALK_IN_RETAIL_HEALTH_CLINIC:
            return walk_in_retail_health_clinic()
        if self is FacilityTypeCode.PLACE_OF_EMPLOYMENT_WORKSITE:
            return place_of_employment_worksite()
        if self is FacilityTypeCode.OFF_CAMPUS_OUTPATIENT_HOSPITAL:
            return off_campus_outpatient_hospital()
        if self is FacilityTypeCode.URGENT_CARE_FACILITY:
            return urgent_care_facility()
        if self is FacilityTypeCode.INPATIENT_HOSPITAL:
            return inpatient_hospital()
        if self is FacilityTypeCode.OUTPATIENT_HOSPITAL:
            return outpatient_hospital()
        if self is FacilityTypeCode.EMERGENCY_ROOM_HOSPITAL:
            return emergency_room_hospital()
        if self is FacilityTypeCode.AMBULATORY_SURGICAL_CENTER:
            return ambulatory_surgical_center()
        if self is FacilityTypeCode.BIRTHING_CENTER:
            return birthing_center()
        if self is FacilityTypeCode.MILITARY_TREATMENT_FACILITY:
            return military_treatment_facility()
        if self is FacilityTypeCode.SKILLED_NURSING_FACILITY:
            return skilled_nursing_facility()
        if self is FacilityTypeCode.NURSING_FACILITY:
            return nursing_facility()
        if self is FacilityTypeCode.CUSTODIAL_CARE_FACILITY:
            return custodial_care_facility()
        if self is FacilityTypeCode.HOSPICE:
            return hospice()
        if self is FacilityTypeCode.AMBULANCE_LAND:
            return ambulance_land()
        if self is FacilityTypeCode.AMBULANCE_AIR_OR_WATER:
            return ambulance_air_or_water()
        if self is FacilityTypeCode.INDEPENDENT_CLINIC:
            return independent_clinic()
        if self is FacilityTypeCode.FEDERALLY_QUALIFIED_HEALTH_CENTER:
            return federally_qualified_health_center()
        if self is FacilityTypeCode.INPATIENT_PSYCHIATRIC_FACILITY:
            return inpatient_psychiatric_facility()
        if self is FacilityTypeCode.PSYCHIATRIC_FACILITY_PARTIAL_HOSPITALIZATION:
            return psychiatric_facility_partial_hospitalization()
        if self is FacilityTypeCode.COMMUNITY_MENTAL_HEALTH_CENTER:
            return community_mental_health_center()
        if self is FacilityTypeCode.INTERMEDIATE_CARE_FACILITY_MENTALLY_RETARDED:
            return intermediate_care_facility_mentally_retarded()
        if self is FacilityTypeCode.RESIDENTIAL_SUBSTANCE_ABUSE_TREATMENT_FACILITY:
            return residential_substance_abuse_treatment_facility()
        if self is FacilityTypeCode.PSYCHIATRIC_RESIDENTIAL_TREATMENT_CENTER:
            return psychiatric_residential_treatment_center()
        if self is FacilityTypeCode.NON_RESIDENTIAL_SUBSTANCE_ABUSE_TREATMENT_FACILITY:
            return non_residential_substance_abuse_treatment_facility()
        if self is FacilityTypeCode.NON_RESIDENTIAL_OPIOID_TREATMENT_FACILITY:
            return non_residential_opioid_treatment_facility()
        if self is FacilityTypeCode.MASS_IMMUNIZATION_CENTER:
            return mass_immunization_center()
        if self is FacilityTypeCode.COMPREHENSIVE_INPATIENT_REHABILITATION_FACILITY:
            return comprehensive_inpatient_rehabilitation_facility()
        if self is FacilityTypeCode.COMPREHENSIVE_OUTPATIENT_REHABILITATION_FACILITY:
            return comprehensive_outpatient_rehabilitation_facility()
        if self is FacilityTypeCode.END_STAGE_RENAL_DISEASE_TREATMENT_FACILITY:
            return end_stage_renal_disease_treatment_facility()
        if self is FacilityTypeCode.STATE_OR_LOCAL_PUBLIC_HEALTH_CLINIC:
            return state_or_local_public_health_clinic()
        if self is FacilityTypeCode.RURAL_HEALTH_CLINIC:
            return rural_health_clinic()
        if self is FacilityTypeCode.INDEPENDENT_LABORATORY:
            return independent_laboratory()
        if self is FacilityTypeCode.OTHER_UNLISTED_FACILITY:
            return other_unlisted_facility()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.service_line_id import ServiceLineId
from .....era_commons.types.claim_status_code_create import ClaimStatusCodeCreate
from .....x_12.resources.v_1.types.claim_adjustment_reason_code import ClaimAdjustmentReasonCode
from .service_line_adjudication_create import ServiceLineAdjudicationCreate


class ClaimAdjudicationCreate(UniversalBaseModel):
    claim_status_code: ClaimStatusCodeCreate
    insurance_paid_amount_cents: typing.Optional[int] = None
    charge_amount_cents: typing.Optional[int] = None
    service_lines: typing.Dict[ServiceLineId, typing.List[ServiceLineAdjudicationCreate]]
    payer_claim_number: typing.Optional[str] = None
    carcs: typing.List[ClaimAdjustmentReasonCode]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .......core.request_options import RequestOptions
from ....common.types.page_token import PageToken
from ....common.types.tag_id import TagId
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.mutable_tag import MutableTag
from .types.tag import Tag
from .types.tag_page import TagPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def get(self, id: TagId, *, request_options: typing.Optional[RequestOptions] = None) -> Tag:
        """
        Gets a tag by TagId.

        Parameters
        ----------
        id : TagId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.tags.v_1.get(
            id="id",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TagPage:
        """
        Gets all tags. Defaults to page size of 1000.

        Parameters
        ----------
        limit : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TagPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.tags.v_1.get_all()
        """
        _response = self._raw_client.get_all(limit=limit, page_token=page_token, request_options=request_options)
        return _response.data

    def create(self, *, request: MutableTag, request_options: typing.Optional[RequestOptions] = None) -> Tag:
        """
        Adds a new tag if it does not already exist, otherwise, returns the existing tag.

        Parameters
        ----------
        request : MutableTag

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.tags.resources.v_1 import (
            MutableTag,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.tags.v_1.create(
            request=MutableTag(
                value="value",
            ),
        )
        """
        _response = self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    def update(
        self, id: TagId, version: str, *, request: MutableTag, request_options: typing.Optional[RequestOptions] = None
    ) -> Tag:
        """
        Updates a tag. The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : TagId

        version : str

        request : MutableTag

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.tags.resources.v_1 import (
            MutableTag,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.tags.v_1.update(
            id="id",
            version="version",
            request=MutableTag(
                value="value",
            ),
        )
        """
        _response = self._raw_client.update(id, version, request=request, request_options=request_options)
        return _response.data

    def deactivate(self, id: TagId, version: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Sets a tag as deactivated.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : TagId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.tags.v_1.deactivate(
            id="id",
            version="version",
        )
        """
        _response = self._raw_client.deactivate(id, version, request_options=request_options)
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def get(self, id: TagId, *, request_options: typing.Optional[RequestOptions] = None) -> Tag:
        """
        Gets a tag by TagId.

        Parameters
        ----------
        id : TagId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.tags.v_1.get(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TagPage:
        """
        Gets all tags. Defaults to page size of 1000.

        Parameters
        ----------
        limit : typing.Optional[int]

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TagPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.tags.v_1.get_all()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_all(limit=limit, page_token=page_token, request_options=request_options)
        return _response.data

    async def create(self, *, request: MutableTag, request_options: typing.Optional[RequestOptions] = None) -> Tag:
        """
        Adds a new tag if it does not already exist, otherwise, returns the existing tag.

        Parameters
        ----------
        request : MutableTag

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.tags.resources.v_1 import (
            MutableTag,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.tags.v_1.create(
                request=MutableTag(
                    value="value",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    async def update(
        self, id: TagId, version: str, *, request: MutableTag, request_options: typing.Optional[RequestOptions] = None
    ) -> Tag:
        """
        Updates a tag. The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : TagId

        version : str

        request : MutableTag

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Tag

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.tags.resources.v_1 import (
            MutableTag,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.tags.v_1.update(
                id="id",
                version="version",
                request=MutableTag(
                    value="value",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(id, version, request=request, request_options=request_options)
        return _response.data

    async def deactivate(
        self, id: TagId, version: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Sets a tag as deactivated.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : TagId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.tags.v_1.deactivate(
                id="id",
                version="version",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.deactivate(id, version, request_options=request_options)
        return _response.data
